Wasefire platform protocol.
This crate defines a high-level protocol between a host and a device. The host initiates
requests and the device responds. Requests and responses use the same Api but with a
different type parameter: Api<Request> and Api<Response> respectively. However, while the
host sends an Api<Request>, the device responds with an ApiResult<T> where T is the
service of the request.
This high-level protocol is eventually wrapped in a lower-level protocol for a given transport, for example USB. The host should provide enough time for the device to respond, but should eventually move on in case no response will ever come, for example when the device is reset before sending the response. Reciprocally, the device should accept a new request from the host and cancel the request it was processing if any.
Modules
Structs
Enums
- Api
- Protocol API parametric over the message direction.
- ApiResult
- ApiVersion
- Returns the device API version.
- Applet
Exit Status - Returns the exit status of an applet, if not running.
- Applet
Install2 - Installs or uninstalls an applet.
- Applet
Metadata0 - Returns the metadata of an applet.
- Applet
Reboot - Reboots an applet.
- Applet
Request - Sends a request to an applet.
- Applet
Response - Reads a response from an applet.
- Applet
Tunnel - Starts a direct tunnel with an applet.
- Platform
Clear Store - Clears the store for the platform and all applets.
- Platform
Info3 - Returns information about the platform.
- Platform
Lock - Locks a platform until reboot.
- Platform
Reboot - Reboots the platform.
- Platform
Update - Updates the platform.
- Platform
Vendor - Calls a vendor-specific platform command.
- Request
- _Applet
Install0 host - (deprecated) Installs an applet.
- _Applet
Install1 host - (deprecated) Installs or uninstalls an applet.
- _Applet
Uninstall0 host - (deprecated) Uninstalls an applet.
- _Platform
Info0 host - (deprecated) Returns platform information (e.g. serial and version).
- _Platform
Info1 host - (deprecated) Returns platform information.
- _Platform
Info2 host - (deprecated) Returns information about the platform.
- _Platform
Update0 host - (deprecated) Updates the platform.
- _Platform
Update Metadata host - (deprecated) Returns the metadata for platform update.
Constants
- VERSION
- Device API version (or maximum supported device API version for host).
Traits
- Connection
host - Connection
Ext host - Service
- Service description.