pub struct Applet0<'a> {
pub kind: AppletKind,
pub metadata: Metadata0<'a>,
pub data: Cow<'a, [u8]>,
}Available on crate feature
host only.Expand description
Applet install (and update).
Fields
kind: AppletKindThe applet kind.
This is redundant with the applet data at this time (pulley and wasm), but provided for convenience.
metadata: Metadata0<'a>The applet metadata.
The CLI or Web UI will suffix this metadata to the applet data in the format supported by the device.
data: Cow<'a, [u8]>The applet data.