Platform0

Struct Platform0 

pub struct Platform0<'a> {
    pub metadata: SideInfo0<'a>,
    pub side_a: Cow<'a, [u8]>,
    pub side_b: Cow<'a, [u8]>,
}
Available on crate feature host only.
Platform update.

Fields

metadata: SideInfo0<'a>

Metadata about the platform.

This metadata is redundant with the platform data for both sides, but contrary to the platform data, this metadata can be accessed by generic tools (without knowning the platform-specific data format).

side_a: Cow<'a, [u8]>

The platform data when stored on the A side.

side_b: Cow<'a, [u8]>

The platform data when stored on the B side.

This can be empty if the platform has only one side.