Hexa

Struct Hexa 

pub struct Hexa<'a>(pub Cow<'a, [u8]>);
Natural number represented in big-endian (possibly with leading zeroes).

This is parsed from and pretty-printed to hexadecimal (including leading zeroes). Leading zeroes are ignored during comparison (the represented natural numbers are compared).

Tuple Fields

0: Cow<'a, [u8]>

Implementations

Source

impl<'a> Hexa<'a>

pub fn reborrow(&self) -> Hexa<'_>

pub fn shrink(&self) -> &[u8]

Strips the leading zeroes.

pub fn extend(&mut self, len: usize)

Extends with leading zeroes.

Methods from Deref<Target = Cow<'a, [u8]>>

1.0.0 · Source

pub fn to_mut(&mut self) -> &mut <B as ToOwned>::Owned

Acquires a mutable reference to the owned form of the data.

Clones the data if it is not already owned.

Examples
use std::borrow::Cow;

let mut cow = Cow::Borrowed("foo");
cow.to_mut().make_ascii_uppercase();

assert_eq!(
  cow,
  Cow::Owned(String::from("FOO")) as Cow<'_, str>
);